@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////////////////////
-//    Copyright 2004-2014, SenseGraphics AB
+//    Copyright 2004-2019, SenseGraphics AB
 //
 //    This file is part of MedX3D.
 //
@@ -118,7 +118,7 @@ bool MedX3DDemoApp::OnInit()
   string urn_config_file = "index.urn";
   char *buffer = getenv( "H3D_URN_CONFIG_FILE" );
   if( buffer ) urn_config_file = buffer;
-  else if( buffer = getenv( "H3D_ROOT" ) ) {
+  else if( ( buffer = getenv( "H3D_ROOT" ) ) ) {
     urn_config_file = buffer;
     urn_config_file += "/index.urn";
   }
@@ -253,7 +253,7 @@ X3DVolumeRenderStyleNode *MedX3DDemoApp::loadRenderStyle( const wxString &name,
   wxString old_path = config->GetPath();
   wxString p = root + wxT("/") + name;
 
-  if( !config->Exists( p ) ) return false;
+  if( !config->Exists( p ) ) return NULL;
   
   config->SetPath( p );
 
