@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////////////////////
-//    Copyright 2006-2014, SenseGraphics AB
+//    Copyright 2006-2019, SenseGraphics AB
 //
 //    This file is part of H3D API.
 //
@@ -33,7 +33,7 @@
 #include <H3D/Viewpoint.h>
 #include <H3D/INIFile.h>
 
-#ifndef WIN32
+#ifndef H3D_WINDOWS
 #include <H3D/X3DKeyDeviceSensorNode.h>
 #include <H3D/MouseSensor.h>
 #endif
@@ -116,9 +116,7 @@ void WxWidgetsWindow::initWindow() {
   }
 #endif
 
-  // TODO: FIX stereo mode
 #ifdef MACOSX
-  // TODO: stereo mode does not work with mac
   attribList[i++] = 0;
 #else
   if( stereo_mode == RenderMode::QUAD_BUFFERED_STEREO ) {
@@ -209,7 +207,6 @@ void WxWidgetsWindow::setFullscreen( bool fullscreen ) {
   if ( last_fullscreen != fullscreen || !fullscreen_initialized ) {
     wxTopLevelWindow * tlw = dynamic_cast< wxTopLevelWindow * >(theWindow);
 #ifndef MACOSX
-    //TODO: fullscreen does not work well on macosx
     if( tlw )
       tlw->ShowFullScreen(fullscreen);
 #endif
@@ -273,7 +270,7 @@ BEGIN_EVENT_TABLE(WxWidgetsWindow::MyWxGLCanvas, wxGLCanvas)
   EVT_SIZE(WxWidgetsWindow::MyWxGLCanvas::OnSize)
   EVT_PAINT(WxWidgetsWindow::MyWxGLCanvas::OnPaint)
   EVT_ERASE_BACKGROUND(WxWidgetsWindow::MyWxGLCanvas::OnEraseBackground)
-#ifndef WIN32
+#ifndef H3D_WINDOWS
   EVT_KEY_DOWN( WxWidgetsWindow::MyWxGLCanvas::OnKeyDown )
   EVT_KEY_UP( WxWidgetsWindow::MyWxGLCanvas::OnKeyUp )
   EVT_CHAR( WxWidgetsWindow::MyWxGLCanvas::OnCharDown )
@@ -471,7 +468,7 @@ string WxWidgetsWindow::getCursorForMode( const string &mode ) {
   return "DEFAULT";
 }
 
-#ifndef WIN32
+#ifndef H3D_WINDOWS
 void WxWidgetsWindow::MyWxGLCanvas::OnKeyDown(wxKeyEvent& event)
 {
   switch( event.GetKeyCode() ) {
