@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////////////////////
-//    Copyright 2004-2014, SenseGraphics AB
+//    Copyright 2004-2019, SenseGraphics AB
 //
 //    This file is part of H3D API.
 //
@@ -46,7 +46,7 @@ namespace H3DVolumeRendererNodeInternals {
 // "(MEDX3D_DIRECTORY)/src/shaders/StyleFunctions.glsl"
 const string H3DVolumeRendererNode::style_function =
     "//////////////////////////////////////////////////////////////////////////////\n"
-    "//    Copyright 2012-2014, SenseGraphics AB\n"
+    "//    Copyright 2012-2019, SenseGraphics AB\n"
     "//\n"
     "//    This file is part of MedX3D.\n"
     "//\n"
@@ -405,7 +405,6 @@ const string H3DVolumeRendererNode::style_function =
     "\n"
     "        // according to X3D spec\n"
     "        float cc = (1.0+dot(L,normal.xyz))*0.5;\n"
-  "        //todo: check if we need to interpolate alpha also?\n"
     "        current_color.rgb += mix(coolColor.rgb, warmColor.rgb, cc); \n"
     "      }\n"
     "    } else {\n"
@@ -517,7 +516,6 @@ const string H3DVolumeRendererNode::style_function =
     "  \n"
     "\n"
     "  vec4 return_color;  \n"
-    "  // TODO: FOG parameters and multiple light sources, spot and attenuation\n"
     "  return_color.rgb = material_emission.rgb + ambient + diffuse + specular; \n"
     "  return_color.a = material_diffuse.a;\n"
     "\n"
