@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////////////////////
-//    Copyright 2004-2014, SenseGraphics AB
+//    Copyright 2004-2019, SenseGraphics AB
 //
 //    This file is part of MedX3D.
 //
@@ -68,11 +68,11 @@ using namespace H3D;
     &X3DComposableVolumeRenderStyleNode::database );
   
   namespace OpacityMapVolumeStyleInternals {
-    FIELDDB_ELEMENT( OpacityMapVolumeStyle, transferFunction, INPUT_OUTPUT );
-    FIELDDB_ELEMENT( OpacityMapVolumeStyle, type, INPUT_OUTPUT );
+    FIELDDB_ELEMENT( OpacityMapVolumeStyle, transferFunction, INPUT_OUTPUT )
+    FIELDDB_ELEMENT( OpacityMapVolumeStyle, type, INPUT_OUTPUT )
 
-    FIELDDB_ELEMENT( OpacityMapVolumeStyle, preintegratedTransferFunction, OUTPUT_ONLY );
-    FIELDDB_ELEMENT( OpacityMapVolumeStyle, preintegratedIntegralStep, INPUT_OUTPUT );
+    FIELDDB_ELEMENT( OpacityMapVolumeStyle, preintegratedTransferFunction, OUTPUT_ONLY )
+    FIELDDB_ELEMENT( OpacityMapVolumeStyle, preintegratedIntegralStep, INPUT_OUTPUT )
   }
   
   OpacityMapVolumeStyle::
@@ -114,7 +114,6 @@ using namespace H3D;
     stepSize->setValue( (H3DFloat) 0.01 );
 
     // routings
-    // TODO: do we need more things to displayList??
     transferFunction->route( displayList );
 
     transferFunction_glsl->route( preintegratedTransferFunction, id );
@@ -153,10 +152,10 @@ using namespace H3D;
     if( data ) {
       Image *image = data->image->getValue();
       if( image ) {
-        Image::PixelType type = image->pixelType();
-        if( type == Image::LUMINANCE ) nr_components_in_data = 1;
-        else if( type == Image::LUMINANCE_ALPHA ) nr_components_in_data = 2;
-        else if( type == Image::RGBA ) nr_components_in_data = 4;
+        Image::PixelType _type = image->pixelType();
+        if( _type == Image::LUMINANCE ) nr_components_in_data = 1;
+        else if( _type == Image::LUMINANCE_ALPHA ) nr_components_in_data = 2;
+        else if( _type == Image::RGBA ) nr_components_in_data = 4;
         else nr_components_in_data = 3;
       } 
     }
@@ -231,7 +230,7 @@ using namespace H3D;
              UNIFORM_ID_(last_orig_sample_color) +
              UNIFORM_ID(preintegratedTransferFunction) + ");\n" +
              UNIFORM_ID(last_orig_sample_color) +
-             " = orig_sample_color;\n";;
+             " = orig_sample_color;\n";
     }
 
 
@@ -267,7 +266,7 @@ using namespace H3D;
     X3DTextureNode *t = static_cast< SFTextureNode * >( routes_in[0] )->getValue();
     H3DFloat integral_step_size = static_cast< SFFloat * >( routes_in[1] )->getValue();
     H3DFloat step_size = static_cast< SFFloat * >( routes_in[2] )->getValue();
-    string type = static_cast< SFString * >( routes_in[3] )->getValue();
+    string _type = static_cast< SFString * >( routes_in[3] )->getValue();
 
     if( !value.get() ) {
       PixelTexture *new_pt = new PixelTexture;
@@ -312,13 +311,13 @@ using namespace H3D;
     }
 
     if ( transfer_function_image ) {
-      if ( type == "preintegrated" ) {
+      if ( _type == "preintegrated" ) {
         createPreIntegrationTable2( transfer_function_image,
                                     dim,
                                     1.0,
                                     piOut );
       }
-      else if ( type == "preintegrated_fast" ) {
+      else if ( _type == "preintegrated_fast" ) {
         createPreIntegrationTableFast( transfer_function_image,
                                        dim,
                                        1.0,
@@ -354,7 +353,7 @@ using namespace H3D;
     // we excplitly check here if the node has changed and rebuild the shader
     // if it has.
     Node *tf = transferFunction->getValue();
-    if( tf != last_loop_tf ) rebuildShader->touch();;
+    if( tf != last_loop_tf ) rebuildShader->touch();
     last_loop_tf = tf;
   }
 
@@ -381,7 +380,7 @@ using namespace H3D;
     
     // compute integral functions
     for( H3DInt32 i = 1; i < input_dim; ++i ) {
-      RGBA col1 = transfer_function->getPixel( i );
+      col1 = transfer_function->getPixel( i );
       H3DFloat tauc = (col0.a + col1.a) / 2;
       r += tauc * (col0.r + col1.r ) / 2;
 
