@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////////////////////
-//    Copyright 2004-2014, SenseGraphics AB
+//    Copyright 2004-2019, SenseGraphics AB
 //
 //    This file is part of H3D API.
 //
@@ -45,11 +45,11 @@ H3DNodeDatabase RayCaster::database( "RayCaster",
                                      &H3DVolumeRendererNode::database );
 
 namespace RayCasterInternals {
-  FIELDDB_ELEMENT( RayCaster, rayStep, INPUT_OUTPUT );
-  FIELDDB_ELEMENT( RayCaster, stopRaysAtGeometries, INPUT_OUTPUT );
-  FIELDDB_ELEMENT( RayCaster, useEmptySpaceSkipping, INPUT_OUTPUT );
-  FIELDDB_ELEMENT( RayCaster, showNonEmptySpace, INPUT_OUTPUT );
-  FIELDDB_ELEMENT( RayCaster, useStochasticJittering, INPUT_OUTPUT );
+  FIELDDB_ELEMENT( RayCaster, rayStep, INPUT_OUTPUT )
+  FIELDDB_ELEMENT( RayCaster, stopRaysAtGeometries, INPUT_OUTPUT )
+  FIELDDB_ELEMENT( RayCaster, useEmptySpaceSkipping, INPUT_OUTPUT )
+  FIELDDB_ELEMENT( RayCaster, showNonEmptySpace, INPUT_OUTPUT )
+  FIELDDB_ELEMENT( RayCaster, useStochasticJittering, INPUT_OUTPUT )
 
   // The glsl vertex shader for perspective projection. Ray direction goes from camera 
   // position towards ray start if perspective projection and constant direction
@@ -87,7 +87,7 @@ namespace RayCasterInternals {
 
   const string raycaster_fs_main = 
     "//////////////////////////////////////////////////////////////////////////////\n"
-    "//    Copyright 2004, SenseGraphics AB\n"
+    "//    Copyright 2004-2019, SenseGraphics AB\n"
     "//\n"
     "//    This file is part of H3D API.\n"
     "//\n"
@@ -802,8 +802,7 @@ void RayCaster::render( X3DVolumeNode *volume ) {
   }
 
 #ifdef H3D_OSX
-  // TODO: investigate further
-  // due to some strange error on OSX (MacBook Pro) we need to add a glBegin/glEnd
+  // Due to some strange error on OSX (MacBook Pro) we need to add a glBegin/glEnd
   // pair in order for the rays to stop in the right place if we have a scene
   // with just a volume data node in it and no other geometries. Otherwise 
   // it seems like the rays are stopped at the wrong position in some places.
@@ -998,11 +997,11 @@ void RayCaster::buildShader( X3DVolumeNode *volume ) {
   // TEMPORARY
   // read fragment shader from file
   /*string stylefunction_file = 
-    "C:/Markus/MedX3D/src/shaders/StyleFunctions.glsl";*/
+    "C:/H3D/MedX3D/src/shaders/StyleFunctions.glsl";*/
   fragmentshader += H3DVolumeRendererNode::style_function;//readShaderFromFile( stylefunction_file );
 
   /*string main_file = 
-    "C:/Markus/MedX3D/src/shaders/RayCaster_FS_main.glsl";*/
+    "C:/H3D/MedX3D/src/shaders/RayCaster_FS_main.glsl";*/
   fragmentshader += RayCasterInternals::raycaster_fs_main;//readShaderFromFile( main_file );
 
   fragmentShaderString->push_back( "glsl:" + fragmentshader );
@@ -1153,7 +1152,6 @@ string RayCaster::addUniforms( X3DVolumeNode *volume ) {
   if( useStochasticJittering->getValue() ) {
     int dim = stochasticJitteringTextureDimension->getValue();
     if( !stochasticJitteringTexture->getValue() ) {
-      int dim = stochasticJitteringTextureDimension->getValue();
       stochasticJitteringTexture->setValue( 
                                            generateStochasticJitteringTexture( dim, dim ) );
     }
