@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////////////////////
-//    Copyright 2004-2014, SenseGraphics AB
+//    Copyright 2004-2019, SenseGraphics AB
 //    Slice based rendering code Copyright 2003-2005, Karljohan Lundin
 //
 //    This file is part of MedX3D.
@@ -59,17 +59,13 @@ H3DNodeDatabase X3DVolumeNode::database( "X3DVolumeNode",
                                           );
   
 namespace X3DVolumeNodeInternals {
-  FIELDDB_ELEMENT( X3DVolumeNode, dimensions, INPUT_OUTPUT );
-  FIELDDB_ELEMENT( X3DVolumeNode, stopRaysAtGeometries, INPUT_OUTPUT );
-  FIELDDB_ELEMENT( X3DVolumeNode, renderer, INPUT_OUTPUT );
-  FIELDDB_ELEMENT( X3DVolumeNode, useEmptySpaceSkipping, INPUT_OUTPUT );
-  FIELDDB_ELEMENT( X3DVolumeNode, emptySpaceSkippingRes, INPUT_OUTPUT );
-  FIELDDB_ELEMENT( X3DVolumeNode, showNonEmptySpace, INPUT_OUTPUT );
-  FIELDDB_ELEMENT( X3DVolumeNode, useStochasticJittering, INPUT_OUTPUT );
-  FIELDDB_ELEMENT( X3DVolumeNode, filterType, INPUT_OUTPUT );
-  FIELDDB_ELEMENT( X3DVolumeNode, filterTexture, OUTPUT_ONLY );
-  FIELDDB_ELEMENT( X3DVolumeNode, bboxCenter, INITIALIZE_ONLY );
-  FIELDDB_ELEMENT( X3DVolumeNode, bboxSize, INITIALIZE_ONLY );
+  FIELDDB_ELEMENT( X3DVolumeNode, dimensions, INPUT_OUTPUT )
+  FIELDDB_ELEMENT( X3DVolumeNode, renderer, INPUT_OUTPUT )
+  FIELDDB_ELEMENT( X3DVolumeNode, emptySpaceSkippingRes, INPUT_OUTPUT )
+  FIELDDB_ELEMENT( X3DVolumeNode, filterType, INPUT_OUTPUT )
+  FIELDDB_ELEMENT( X3DVolumeNode, filterTexture, OUTPUT_ONLY )
+  FIELDDB_ELEMENT( X3DVolumeNode, bboxCenter, INITIALIZE_ONLY )
+  FIELDDB_ELEMENT( X3DVolumeNode, bboxSize, INITIALIZE_ONLY )
 
 
   // debug fields for visualizing empty space textures. Normally not used.
@@ -346,10 +342,10 @@ void X3DVolumeNode::initialize() {
 }
 
 void X3DVolumeNode::SurfaceNormals::update() {
-  X3DTexture3DNode *voxels = 
+  X3DTexture3DNode *_voxels = 
     static_cast<SFTexture3DNode*>( routes_in[0] )->getValue();
-  if( voxels ) {
-    Image *im = voxels->image->getValue();
+  if( _voxels ) {
+    Image *im = _voxels->image->getValue();
     if( im ) {
       Console(3) << "Computing surface normals" << endl;
   
@@ -799,13 +795,13 @@ void getMinMaxData( Image *image,
 }
 
 void X3DVolumeNode::SFEmptySpaceMinMaxTexture3D::update() {
-  X3DTexture3DNode *voxels = 
+  X3DTexture3DNode *_voxels = 
     static_cast< SFTexture3DNode * >( routes_in[0] )->getValue();
   H3DInt32 res = static_cast< SFInt32 * >( routes_in[1] )->getValue();
   
   // get the image data
   Image *image = NULL;
-  if( voxels ) image = voxels->image->getValue();
+  if( _voxels ) image = _voxels->image->getValue();
 
   // if no image data, set field to null
   if( !image ) {
@@ -952,27 +948,27 @@ void X3DVolumeNode::UseSlicingField::onValueChange( const bool &v ) {
 
 void X3DVolumeNode::SFVolumeRendererNode::onAdd( Node *n ) {
   SFVolumeRendererNodeBase::onAdd( n );
-  H3DVolumeRendererNode *renderer = 
+  H3DVolumeRendererNode *_renderer = 
     static_cast< H3DVolumeRendererNode * >( n );
   X3DVolumeNode *volume = static_cast< X3DVolumeNode * >(getOwner());
   if( n ) {
-    renderer->addVolume( volume );
+    _renderer->addVolume( volume );
   }
 }
 
 
 void X3DVolumeNode::SFVolumeRendererNode::onRemove( Node *n ) {
-  H3DVolumeRendererNode *renderer = 
+  H3DVolumeRendererNode *_renderer =
     static_cast< H3DVolumeRendererNode * >( n );
   X3DVolumeNode *volume = static_cast< X3DVolumeNode * >(getOwner());
   if( n ) {
-    renderer->removeVolume( volume );
+    _renderer->removeVolume( volume );
   }
   SFVolumeRendererNodeBase::onRemove( n );
 }
 
 string X3DVolumeNode::uniqueShaderName( const string &base_name ) {
-  unsigned long sid = (unsigned long)(this);
+  uintptr_t sid = uintptr_t(this);
   ostringstream ostr;
   ostr << hex << sid;
   return base_name + ostr.str();
